==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/MaintainerFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class MaintainerFluentImpl<A extends io.dekorate.helm.config.MaintainerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.dekorate.helm.config.MaintainerFluent<A>{
  public MaintainerFluentImpl() {
  }
  public MaintainerFluentImpl(io.dekorate.helm.config.Maintainer instance) {
    this.withName(instance.getName()); 
    this.withEmail(instance.getEmail()); 
    this.withUrl(instance.getUrl()); 
  }
  private java.lang.String name;
  private java.lang.String email;
  private java.lang.String url;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getEmail() {
    return this.email;
  }
  public A withEmail(java.lang.String email) {
    this.email=email; return (A) this;
  }
  public java.lang.Boolean hasEmail() {
    return this.email != null;
  }
  
  /**
   * Method is deprecated. use withEmail instead.
   */
  @java.lang.Deprecated
  public A withNewEmail(java.lang.String arg0) {
    return (A)withEmail(new String(arg0));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MaintainerFluentImpl that = (MaintainerFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (email != null ? !email.equals(that.email) :that.email != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  email,  url,  super.hashCode());
  }
  
}

==> helm-annotations-2.11.3-sources.jar: io/dekorate/helm/config/MaintainerFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MaintainerFluentImpl<A extends MaintainerFluent<A>> extends BaseFluent<A> implements MaintainerFluent<A>{
  public MaintainerFluentImpl() {
  }
  public MaintainerFluentImpl(io.dekorate.helm.config.Maintainer instance) {
    this.withName(instance.getName()); 
    this.withEmail(instance.getEmail()); 
    this.withUrl(instance.getUrl()); 
  }
  private String name;
  private java.lang.String email;
  private java.lang.String url;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public java.lang.String getEmail() {
    return this.email;
  }
  public A withEmail(java.lang.String email) {
    this.email=email; return (A) this;
  }
  public java.lang.Boolean hasEmail() {
    return this.email != null;
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MaintainerFluentImpl that = (MaintainerFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (email != null ? !email.equals(that.email) :that.email != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  email,  url,  super.hashCode());
  }
  public java.lang.String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (email != null) { sb.append("email:"); sb.append(email + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}
